NLSL: eprmat.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

eprmat.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/12/15
2 c*********************************************************************
3 c =========================
4 c module EPRMAT
5 c =========================
6 c
7 c Declarations of Z matrix for EPRLL
8 c
9 c These declarations include the additional jzmat and kzmat
10 c arrays used with the updated versions of MATRLL and SCMVM
11 c subroutines.
12 c
13 c Notes:
14 c 1) The dimensions of the arrays declared here are
15 c determined by parameters declared in the module
16 c nlsdim, which is used below.
17 c
18 c 2) The diagonal elements of Z are stored in the
19 c complex array zdiag. The upper diagonal of the
20 c real and imaginary parts of Z are stored
21 c separately by row in the zmat array, skipping
22 c zero elements. Imaginary elements are packed
23 c starting at the beginning of zmat, and real
24 c elements starting at the upper limit of zmat.
25 c Companion arrays jzmat and kzmat respectively
26 c give the the locations of the first imaginary
27 c and real elements of each row of Z within zmat,
28 c and izmat gives the column index corresponding
29 c to each element in zmat.
30 c
31 c 3) This was originally a common block named scmat,
32 c but all dependent subprograms simply included
33 c file eprmat.inc, so the module is named eprmat.
34 c
35 c zdiag : diagonal elements of Z
36 c zmat : real and imaginary elements of Z upper diagonal
37 c jzmat(i) : index of 1st imaginary element of row i in zmat
38 c kzmat(i) : index of 1st real element of row i in zmat
39 c izmat(i) : Z column index of ith element of zmat
40 c
41 c written by DJS 11-SEP-87
42 c
43 c*********************************************************************
44 c
45 module eprmat
46 use nlsdim
47 implicit none
48 c
49 double precision, save :: zmat(mxel), zdiag(2,mxdim)
50 integer, save :: izmat(mxel), jzmat(mxdim+1), kzmat(mxdim+1)
51 c
52 end module eprmat
eprmat
Definition: eprmat.f90:45
eprmat::jzmat
integer, dimension(mxdim+1), save jzmat
Definition: eprmat.f90:50
eprmat::kzmat
integer, dimension(mxdim+1), save kzmat
Definition: eprmat.f90:50
eprmat::izmat
integer, dimension(mxel), save izmat
Definition: eprmat.f90:50
eprmat::zmat
double precision, dimension(mxel), save zmat
Definition: eprmat.f90:49
nlsdim::mxel
integer, parameter mxel
Definition: nlsdim.f90:39
nlsdim
Definition: nlsdim.f90:36
nlsdim::mxdim
integer, parameter mxdim
Definition: nlsdim.f90:39
eprmat::zdiag
double precision, dimension(2, mxdim), save zdiag
Definition: eprmat.f90:49